"""
``django_fields_iterator`` provides the ``FieldsIterator`` class that allow to iterate on some or
all of the fields of a model.
"""

# Provide access to classes directly from the package root
from .iterator import FieldsIterator
from .types import FieldTypes


# Info for setup
__author__ = 'Stephane "TWidi" Angel'
__contact__ = 's.angel@twidi.com'
__homepage__ = 'https://github.com/magencydigital/'
__license__ = 'BSD'
__version__ = '1.2.1'
VERSION = tuple(__version__.split('.'))


